import type { PropsConfig, WidgetSlotContext, SlotContent, Directive, Widget } from '@agnos-ui/svelte-headless/types';
import type { EmblaPluginType, EmblaPluginsType, EmblaCarouselType } from 'embla-carousel';
/**
 * Retrieve a shallow copy of the default Carousel config
 * @returns the default Carousel config
 */
declare const export_getCarouselDefaultConfig: () => CarouselProps<any>;
export { export_getCarouselDefaultConfig as getCarouselDefaultConfig };
/**
 * Create a Carousel with given config props
 *
 * @template SlideData - The type of the data for each slide.
 * @param config - an optional carousel config
 * @returns a CarouselWidget
 */
declare const export_createCarousel: <SlideData extends {
    id: string;
}>(config?: PropsConfig<CarouselProps<SlideData>>) => CarouselWidget<SlideData>;
export { export_createCarousel as createCarousel };
/**
 * Represents the context for a carousel.
 *
 * @template SlideData - The type of data used by each slide in the carousel.
 */
export type CarouselContext<SlideData extends {
    id: string;
}> = WidgetSlotContext<CarouselWidget<SlideData>>;
/**
 * Represents the context for a carousel slide.
 *
 * @template SlideData - The type of data used by each slide in the carousel.
 */
export type CarouselSlideContext<SlideData extends {
    id: string;
}> = WidgetSlotContext<CarouselWidget<SlideData>> & SlideData;
/**
 * Represents the state of a carousel component.
 *
 * @template SlideData - The type of data used by each slide in the carousel.
 */
export interface CarouselState<SlideData extends {
    id: string;
}> {
    /**
     * is the carousel currently scrolling
     */
    scrolling: boolean;
    /**
     * can carousel scroll to previous slide
     */
    canScrollPrev: boolean;
    /**
     * can carousel scroll to next slide
     */
    canScrollNext: boolean;
    /**
     * selected scroll snap
     */
    selectedScrollSnap: number;
    /**
     * is the carousel initialized
     */
    initialized: boolean;
    /**
     * If `true`, 'previous' and 'next' navigation arrows will be visible.
     */
    showNavigationArrows: boolean;
    /**
     * If `true`, navigation indicators at the bottom of the slide will be visible.
     */
    showNavigationIndicators: boolean;
    /**
     * Choose content direction between `ltr` and `rtl`
     *
     * @see {@link https://www.embla-carousel.com/api/options/#direction}
     * @defaultValue `'ltr'`
     */
    direction: 'ltr' | 'rtl';
    /**
     * CSS classes to be applied on the widget main container
     *
     * @defaultValue `''`
     */
    className: string;
    /**
     * Class name to apply to the container of the carousel.
     *
     * @defaultValue `''`
     */
    containerClass: string;
    /**
     * Class name to apply to each slide in the carousel.
     *
     * @defaultValue `''`
     */
    slideClass: string | ((slideContext: {
        id: string;
        index: number;
        active: boolean;
    }) => string);
    /**
     * The data for each slide in the carousel.
     *
     * @defaultValue `[]`
     */
    slidesData: SlideData[];
    /**
     * The structure of the carousel.
     *
     * @defaultValue `undefined`
     */
    structure: SlotContent<CarouselContext<SlideData>>;
    /**
     * The navigation layer of the carousel.
     *
     * @defaultValue `undefined`
     */
    navigation: SlotContent<CarouselContext<SlideData>>;
    /**
     * The content of each slide in the carousel.
     *
     * @defaultValue `undefined`
     */
    slide: SlotContent<CarouselSlideContext<SlideData>>;
    /**
     * The aria-live attribute value for the carousel container.
     *
     * @defaultValue `'polite'`
     */
    ariaLive: string;
}
/**
 * Interface representing the properties for a carousel component.
 *
 * @template SlideData - The type of data used by each slide in the carousel.
 */
export interface CarouselProps<SlideData extends {
    id: string;
}> {
    /**
     * Plugins to extend the carousel with additional features
     * @defaultValue `[]`
     */
    plugins: EmblaPluginType[];
    /**
     * Aria label for navigation indicators
     */
    ariaIndicatorLabel: (index: number) => string;
    /**
     * Aria label for previous button
     */
    ariaPrevLabel: string;
    /**
     * Aria label for next button
     */
    ariaNextLabel: string;
    /**
     * Align the slides relative to the carousel viewport
     *
     * @see {@link https://www.embla-carousel.com/api/options/#align}
     * @defaultValue `'center'`
     */
    align: 'start' | 'center' | 'end';
    /**
     * Enables choosing a custom container element which holds the slides. By default, Embla will choose the first direct child element of the root element. Provide a valid CSS selector string.
     *
     * @see {@link https://www.embla-carousel.com/api/options/#container}
     */
    container: string | null;
    /**
     * Clear leading and trailing empty space that causes excessive scrolling
     *
     * @see {@link https://www.embla-carousel.com/api/options/#containScroll}
     * @defaultValue `'trimSnaps'`
     */
    containScroll: false | 'trimSnaps' | 'keepSnaps';
    /**
     * Choose content direction between `ltr` and `rtl`
     *
     * @see {@link https://www.embla-carousel.com/api/options/#direction}
     * @defaultValue `'ltr'`
     */
    direction: 'ltr' | 'rtl';
    /**
     * Enables momentum scrolling
     *
     * @see {@link https://www.embla-carousel.com/api/options/#dragFree}
     * @defaultValue `false`
     */
    dragFree: boolean;
    /**
     * Drag threshold in pixels
     *
     * @see {@link https://www.embla-carousel.com/api/options/#dragThreshold}
     * @defaultValue `10`
     */
    dragThreshold: number;
    /**
     * Set scroll duration when triggered by any of the API methods
     *
     * @see {@link https://www.embla-carousel.com/api/options/#duration}
     * @defaultValue `25`
     */
    duration: number;
    /**
     * Enables infinite looping
     *
     * @see {@link https://www.embla-carousel.com/api/options/#loop}
     * @defaultValue `false`
     */
    loop: boolean;
    /**
     * Allow the carousel to skip scroll snaps if it's dragged vigorously
     *
     * @see {@link https://www.embla-carousel.com/api/options/#skipsnaps}
     * @defaultValue `false`
     */
    skipSnaps: boolean;
    /**
     * If `true`, 'previous' and 'next' navigation arrows will be visible.
     */
    showNavigationArrows: boolean;
    /**
     * If `true`, navigation indicators at the bottom of the slide will be visible.
     */
    showNavigationIndicators: boolean;
    /**
     * CSS classes to be applied on the widget main container
     *
     * @defaultValue `''`
     */
    className: string;
    /**
     * Class name to apply to the container of the carousel.
     *
     * @defaultValue `''`
     */
    containerClass: string;
    /**
     * Class name to apply to each slide in the carousel.
     *
     * @defaultValue `''`
     */
    slideClass: string | ((slideContext: {
        id: string;
        index: number;
        active: boolean;
    }) => string);
    /**
     * The data for each slide in the carousel.
     *
     * @defaultValue `[]`
     */
    slidesData: SlideData[];
    /**
     * The structure of the carousel.
     *
     * @defaultValue `undefined`
     */
    structure: SlotContent<CarouselContext<SlideData>>;
    /**
     * The navigation layer of the carousel.
     *
     * @defaultValue `undefined`
     */
    navigation: SlotContent<CarouselContext<SlideData>>;
    /**
     * The content of each slide in the carousel.
     *
     * @defaultValue `undefined`
     */
    slide: SlotContent<CarouselSlideContext<SlideData>>;
    /**
     * The aria-live attribute value for the carousel container.
     *
     * @defaultValue `'polite'`
     */
    ariaLive: string;
}
/**
 * Represents the directives for a carousel component.
 */
export interface CarouselDirectives {
    /**
     * A directive to be applied to each slide in the carousel.
     */
    slide: Directive<{
        id: string;
        index: number;
    }>;
    /**
     * A directive to be applied to container of the carousel.
     */
    container: Directive;
    /**
     * the root directive
     */
    root: Directive;
    /**
     * A directive to be applied to a navigation button allowing to scroll to the previous slide.
     */
    scrollPrev: Directive;
    /**
     * A directive to be applied to a navigation button allowing to scroll to the next slide.
     */
    scrollNext: Directive;
    /**
     * A directive to be applied to a tab list allowing to navigate to the corresponding slide.
     * This directive adds the role `tablist` and is recommended to be used together with {@link tabIndicator}.
     */
    tabList: Directive;
    /**
     * A directive to be applied to a navigation indicator allowing to scroll to the corresponding slide.
     * As this directive adds the role `tab` to the element, it is recommended to use it on a button or a link and the parent element should have the {@link tabList} directive attached.
     */
    tabIndicator: Directive<{
        index: number;
        id: string;
        jump?: boolean;
    }>;
}
/**
 * Represents a carousel widget with specific properties, state, API, and directives.
 *
 * @template SlideData - The type of the data for each slide.
 */
export type CarouselWidget<SlideData extends {
    id: string;
}> = Widget<CarouselProps<SlideData>, CarouselState<SlideData>, CarouselApi, CarouselDirectives>;
/**
 * Represents the API for a carousel component.
 */
export interface CarouselApi {
    /**
     * Scroll to the previous snap point if possible.
     * @param jump - scroll instantly
     */
    scrollPrev: (jump?: boolean) => void;
    /**
     * Scroll to the next snap point if possible.
     * @param jump - scroll instantly
     */
    scrollNext: (jump?: boolean) => void;
    /**
     * Scroll to a snap point by index
     * @param index - the snap point index
     * @param jump - scroll instantly
     */
    scrollTo: (index: number, jump?: boolean) => void;
    /**
     * Retrieve the enabled plugins
     */
    plugins: () => EmblaPluginsType | undefined;
    /**
     * Retrieve the inner EmblaApi object
     */
    emblaApi: () => EmblaCarouselType | undefined;
}
